/*
***  MULTIMATERIAL FROM FILES v1.0  ***

Script Name:	MultimaterialFromFiles_v1.0.ms
Compatible:		3dsMax 2015 and higher
Version:		1.0
Release date:	August 20, 2024
Last update:	August 20, 2024
Code by:		Hernan A. Rodenstein
Website:		www.splinedynamics.com/free-3dsmax-scripts/

Description: 
Creates a multimaterial and populate the submaterials with a group of texture files selected from your drive, as diffuse textures. Then applies it to the selected object/s.

Features:
* 6 material types from different render engines supported: Physical material, Arnold Standard Surface, VRay material, Corona material, FStorm, Standard material.
* Option to add a Material Modifier to switch between material IDs.

Revision History: 

- (first version)

*/

macroScript Multimaterial_from_files
category:"Spline Dynamics - free scripts"
tooltip:"Multimaterial from Files"
buttontext:"MMFF"
(
	global mmff_floater
	global mmff_pos = [500,300]

	rollout mmff_cont "Mutimaterial from Files"
	(
		fn isValidMaterialClass idx =
		(
			matClassArr = #(PhysicalMaterial, ai_standard_surface, VRayMtl, CoronaMtl, FStorm, Standardmaterial)
			isValid = (if (findItem material.classes matClassArr[idx])==0 then false else true)
		)
		
		fn createMaterial idx txMap =
		(
			mat = case idx of (
				1: PhysicalMaterial base_color_map:txMap
				2: ai_standard_surface base_shader:txMap
				3: VRayMtl texmap_diffuse:txMap
				4: CoronaMtl texmapDiffuse:txMap
				5: FStorm diffuse_tex:txMap
				default: Standardmaterial diffuseMap:txMap
			)
		)
		
		-- *** Creates Multimaterial from selected texture files ***
		fn multiMatFromTextureFiles matTypeIdx =
		(			
			theMat = undefined
			
			theDialog = dotNetObject "System.Windows.Forms.OpenFileDialog" --create a OpenFileDialog
			theDialog.title = "Select Multiple Bitmap Files" --set the title

			theDialog.Multiselect = true --allow multiple files to be selected

			-- Change this section as you would a normal max file open dialogue to filter the required image types
			theDialog.Filter = "Image Files (*.jpg, *.jpeg, *.png, *.tif, *.tga, *.dds, *.bmp)|*.jpg; *.jpeg; *.png; *.tif; *.tga; *.dds; *.bmp|JPG, PNG Files (*.jpg, *.jpeg, *.png)|*.jpg; *.jpeg; *.png" --specify the filter
			theDialog.FilterIndex = 2 --set the filter drop-down list to All Files
			result = theDialog.showDialog() --display the dialog, get result into variable

			result.ToString() --when closed, convert the result to string
			result.Equals result.OK --returns TRUE if OK was pressed, FALSE otherwise
			result.Equals result.Cancel --returns TRUE if Cancel was pressed, FALSE otherwise

			FilesArr = theDialog.fileNames --the selected filenames will be returned as an array

			if (FilesArr.count > 0) then
			(
				--Create Materials
				matsArr = #()
				for nfile in FilesArr do
				(
					txMap = Bitmaptexture fileName:nfile
					mat = createMaterial matTypeIdx txMap
					assignNewName mat
					showTexturemap mat true
					append matsArr mat
				)	
				--Create Multimaterial
				theMat = multiMaterial()
				theMat.numsubs = FilesArr.count
				theMat.materialList = matsArr
			)
			else
			(
				messagebox "You must select at least one texture file!"
			)
			theMat
		)
		
		dropdownlist dplistMaterial "Material type" items:#("Physical Material", "Arnold Standard Surface", "VRay material", "Corona material", "FStorm material", "Standard material") selection:1 align:#center offset:[0,4]
		checkbox chbAddMaterialMod "Add Material Modifier" checked:true align:#left offset:[0,4] 
		button btnSelectFiles "Select Files..." width:160 height:30 align:#center offset:[0,6]
		
		label txtAbout1 "Mutimaterial from Files v1.0" align:#center offset:[0,12]
		hyperLink hlinkAbout "www.SplineDynamics.com" color:(color 135 170 38) hoverColor:yellow visitedColor:(color 135 170 38) address:"https://www.splinedynamics.com" align:#center offset:[0,-2]
		
		-- *** Align multiple objects ***
		on btnSelectFiles pressed do
		(			
			if selection.count==0 then (	
			
				messageBox "Please first select one or more objects to apply the material to."
				
			) else (	
				undo "Multimaterial from files" on (
					
					matTypeIdx = dplistMaterial.selection
					
					if (isValidMaterialClass matTypeIdx) then (
						
						theMat = multiMatFromTextureFiles matTypeIdx
						
						if theMat!=undefined then (
							-- Assign material to selected objs
							for obj in selection do (
								obj.material = theMat
								if chbAddMaterialMod.state==true then addModifier obj (Materialmodifier())
							)
						)
						
					) else (
						messageBox "Invalid material type. Missing renderer.\nPlease choose another type."
					)					
				)
			)
		)
	) -- end rollout

	try (
		closerolloutfloater mmff_floater
		mmff_pos = mmff_floater.pos
	)catch()
	mmff_floater = newrolloutfloater "Mutimaterial from Files" 200 200
	mmff_floater.pos = mmff_pos
	addrollout mmff_cont mmff_floater rolledup:false	
)